\name{plotMosaic}
\alias{plotMosaic}
\alias{plot.mosaic}

\title{Plots a Mosaic Fit}
\description{\code{plotMosaic} plots a hybrid dataset along with a
  specified model.  \code{plot} can be applied directly to the output of
  \code{\link{fit.mosaic}} and by default plots the dataset and most
  likely best fit model.  If \code{nsteps} is specified it plots a best fit
  model with \code{nsteps} steps}

\usage{
plotMosaic(d, m, pch=20, lcol="blue", ...)
\method{plot}{mosaic}(x, nsteps=NULL, ...)
}

\arguments{
  \item{d}{a hybrid zone data set as defined in
    \code{\link{fit.mosaic}}}
  \item{m}{a model as defined in \code{\link{fit.mosaic}}}
  \item{pch}{plot style of hybrid zone data}
  \item{lcol}{line color of best fit model}
  \item{nsteps}{number of steps}
  \item{x}{object of class \code{mosaic}}
   \item{...}{additional arguments to \code{plotMosaic} (when using
    \code{plot}) and from \code{plotMosaic} to the underlying \code{plot}
    functions.}
}

\examples{
\dontrun{
data(hybrid.zone)
res <- fit.mosaic(hybrid.zone, 0.05)
plot(res)
plotMosaic(hybrid.zone, res[[length(res)]]$best.model)
}
}

\references{
    M'Gonigle, L.K., FitzJohn, R.G. 2010. Assortative Mating and Spatial
    Structure in Hybrid Zones. Evolution: 64: 444--445.
}
\author{LKM & RGF}